scruffy/bulk_data
A type describing Scryfall’s Bulk Data object, a description of a downloadable file containing Scryfall’s card data.
See https://scryfall.com/docs/api/bulk-data for the upstream reference.
Types
A description of a downloadable file containing Scryfall data, such as every card object on Scryfall.
pub type BulkData {
BulkData(
id: String,
uri: uri.Uri,
bulk_data_type: BulkDataType,
updated_at: Int,
name: String,
description: String,
jsonl_download_uri: uri.Uri,
compressed_size: Int,
)
}
Constructors
-
BulkData( id: String, uri: uri.Uri, bulk_data_type: BulkDataType, updated_at: Int, name: String, description: String, jsonl_download_uri: uri.Uri, compressed_size: Int, )
The kind of data a Bulk Data file contains.
pub type BulkDataType {
OracleCards
UniqueArtwork
DefaultCards
AllCards
Rulings
ArtTags
OracleTags
}
Constructors
-
OracleCards -
UniqueArtwork -
DefaultCards -
AllCards -
Rulings -
ArtTags -
OracleTags
Values
pub fn bulk_data_schema() -> glon.JsonSchema(BulkData)
pub fn bulk_data_type_schema() -> glon.JsonSchema(BulkDataType)