scruffy/catalog
A type describing Scryfall’s Catalog object, a list of Magic-related strings such as artist names or word bank entries.
See https://scryfall.com/docs/api/catalogs for the upstream reference.
Types
A list of t values returned by one of Scryfall’s catalog endpoints.
uri is present on the /catalog/* endpoints but absent from
/cards/autocomplete, which returns this same shape otherwise.
pub type Catalog(t) {
Catalog(
uri: option.Option(uri.Uri),
total_values: Int,
data: List(t),
)
}
Constructors
-
Catalog( uri: option.Option(uri.Uri), total_values: Int, data: List(t), )
Values
pub fn catalog_schema(
of item_schema: glon.JsonSchema(t),
) -> glon.JsonSchema(Catalog(t))