scruffy/layout
A type describing the physical layouts a card can be printed in.
Types
The physical layout of a card, such as Split or Transform.
pub type Layout {
Normal
Split
Flip
Transform
ModalDoubleFacedCard
Meld
Leveler
Class
Case
Saga
Adventure
Prepare
Mutate
Prototype
Battle
Planar
Scheme
Vanguard
Token
DoubleFacedToken
Emblem
Augment
Host
ArtSeries
ReversibleCard
}
Constructors
-
Normal -
Split -
Flip -
Transform -
ModalDoubleFacedCard -
Meld -
Leveler -
Class -
Case -
Saga -
Adventure -
Prepare -
Mutate -
Prototype -
Battle -
Planar -
Scheme -
Vanguard -
Token -
DoubleFacedToken -
Emblem -
Augment -
Host -
ArtSeries -
ReversibleCard
Values
pub fn layout_schema() -> glon.JsonSchema(Layout)