scruffy/card_symbol
A type describing Scryfall’s Card Symbol object, used to render mana costs, the tap symbol, and other symbols found in oracle text.
See https://scryfall.com/docs/api/card-symbols for the upstream reference.
Types
A symbol that can appear in a card’s mana cost or oracle text, such as
{T} or {2/W}.
pub type CardSymbol {
CardSymbol(
symbol: String,
loose_variant: option.Option(String),
english: String,
transposable: Bool,
represents_mana: Bool,
mana_value: option.Option(Float),
appears_in_mana_costs: Bool,
funny: Bool,
colors: List(color.Color),
hybrid: Bool,
phyrexian: Bool,
gatherer_alternates: option.Option(List(String)),
svg_uri: option.Option(uri.Uri),
)
}
Constructors
-
CardSymbol( symbol: String, loose_variant: option.Option(String), english: String, transposable: Bool, represents_mana: Bool, mana_value: option.Option(Float), appears_in_mana_costs: Bool, funny: Bool, colors: List(color.Color), hybrid: Bool, phyrexian: Bool, gatherer_alternates: option.Option(List(String)), svg_uri: option.Option(uri.Uri), )
Values
pub fn card_symbol_schema() -> glon.JsonSchema(CardSymbol)