scruffy/scryfall_list
A type describing Scryfall’s List object, the paginated envelope most Scryfall endpoints wrap their results in.
See https://scryfall.com/docs/api/lists for the upstream reference.
Types
A single page of t values returned by a Scryfall list endpoint.
pub type ScryfallList(t) {
ScryfallList(
data: List(t),
has_more: Bool,
next_page: option.Option(uri.Uri),
total_cards: option.Option(Int),
warnings: option.Option(List(String)),
)
}
Constructors
-
ScryfallList( data: List(t), has_more: Bool, next_page: option.Option(uri.Uri), total_cards: option.Option(Int), warnings: option.Option(List(String)), )
Values
pub fn scryfall_list_schema(
of item_schema: glon.JsonSchema(t),
) -> glon.JsonSchema(ScryfallList(t))